@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # -*- test-case-name: pytils.test.test_dt -*-
-# pytils - simple processing for russian strings
-# Copyright (C) 2006-2007  Yury Yurevich
+# pytils - russian-specific string utils
+# Copyright (C) 2006-2008  Yury Yurevich
 #
 # http://www.pyobject.ru/projects/pytils/
 #
@@ -18,12 +18,12 @@
 Russian dates without locales
 """
 
-__id__ = __revision__ = "$Id: dt.py 102 2007-07-12 12:33:36Z the.pythy $"
-__url__ = "$URL: https://pythy.googlecode.com/svn/tags/pytils/0_2_2/pytils/dt.py $"
-
 import datetime
 
-from pytils import numeral, utils
+from pytils import numeral
+from pytils.utils import takes, returns, optional, check_positive
+
+import utils
 
 DAY_ALTERNATIVES = {
     1: (u"вчера", u"завтра"),
@@ -76,7 +76,12 @@ DAY_NAMES = (
     (u"вск", u"воскресенье", u"воскресенье", u"в\xa0")
     )  #: Day names (abbreviated, full, inflected, preposition)
 
-
+@takes((int, float, datetime.datetime),
+       optional(int),
+       optional((int, float, datetime.datetime)),
+       accuracy=optional(int),
+       to_time=optional((int, float, datetime.datetime)))
+@returns(unicode)
 def distance_of_time_in_words(from_time, accuracy=1, to_time=None):
     """
     Represents distance of time in words
@@ -94,7 +99,7 @@ def distance_of_time_in_words(from_time, accuracy=1, to_time=None):
     @return: distance of time in words
     @rtype: unicode
 
-    @raise TypeError: input parameters' check failed
+    @raise L{pytils.err.InputParameterError}: input parameters' check failed
     @raise ValueError: accuracy is lesser or equal zero
     """
     current = False
@@ -103,10 +108,7 @@ def distance_of_time_in_words(from_time, accuracy=1, to_time=None):
         current = True
         to_time = datetime.datetime.now()
 
-    utils.check_type('from_time', (int, float, datetime.datetime))
-    utils.check_type('to_time', (int, float, datetime.datetime))
-    utils.check_type('accuracy', int)
-    utils.check_positive('accuracy', strict=True)
+    check_positive(accuracy, strict=True)
 
     if not isinstance(from_time, datetime.datetime):
         from_time = datetime.datetime.fromtimestamp(from_time)
@@ -194,7 +196,17 @@ def distance_of_time_in_words(from_time, accuracy=1, to_time=None):
 
     return final_str
 
-
+@takes(optional(unicode),
+       optional((datetime.date, datetime.datetime)),
+       optional(bool),
+       optional(bool),
+       optional(bool),
+       format=optional(unicode),
+       date=optional((datetime.date, datetime.datetime)),
+       inflected=optional(bool),
+       inflected_day=optional(bool),
+       preposition=optional(bool))
+@returns(unicode)
 def ru_strftime(format=u"%d.%m.%Y", date=None, inflected=False, inflected_day=False, preposition=False):
     """
     Russian strftime without locale
@@ -218,12 +230,10 @@ def ru_strftime(format=u"%d.%m.%Y", date=None, inflected=False, inflected_day=Fa
     @return: strftime string
     @rtype: unicode
 
-    @raise TypeError: input parameters' check failed
+    @raise L{pytils.err.InputParameterError}: input parameters' check failed
     """
     if date is None:
         date = datetime.datetime.today()
-    utils.check_type('date', (datetime.date, datetime.datetime))
-    utils.check_type('format', unicode)
 
     weekday = date.weekday()
     
