@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-# pytils - simple processing for russian strings
-# Copyright (C) 2006-2007  Yury Yurevich
+# pytils - russian-specific string utils
+# Copyright (C) 2006-2008  Yury Yurevich
 #
 # http://www.pyobject.ru/projects/pytils/
 #
@@ -16,9 +16,6 @@
 """
 Unit tests for pytils
 """
-
-__id__ = __revision__ = "$Id: __init__.py 102 2007-07-12 12:33:36Z the.pythy $"
-__url__ = "$URL: https://pythy.googlecode.com/svn/tags/pytils/0_2_2/pytils/test/__init__.py $"
 __all__ = ["test_numeral", "test_dt", "test_translit", "test_utils"]
 
 import unittest
@@ -47,6 +44,12 @@ def get_suite():
 
     return suite
 
+def run_tests_from_module(module, verbosity=1):
+    """Run unit-tests for single module"""
+    suite = unittest.TestSuite()
+    loader = unittest.defaultTestLoader
+    suite.addTest(loader.loadTestsFromModule(module))
+    unittest.TextTestRunner(verbosity=verbosity).run(suite)
 
 def run(verbosity=1):
     """Run all unit-test of pytils"""
@@ -55,3 +58,4 @@ def run(verbosity=1):
 
 if __name__ == '__main__':
     run(2)
+
