@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-# pytils - simple processing for russian strings
-# Copyright (C) 2006-2007  Yury Yurevich
+# pytils - russian-specific string utils
+# Copyright (C) 2006-2008  Yury Yurevich
 #
 # http://www.pyobject.ru/projects/pytils/
 #
@@ -17,9 +17,7 @@
 Unit tests for pytils' templatetags for Django web framework
 """
 
-__id__ = __revision__ = "$Id: __init__.py 102 2007-07-12 12:33:36Z the.pythy $"
-__url__ = "$URL: https://pythy.googlecode.com/svn/tags/pytils/0_2_2/pytils/test/templatetags/__init__.py $"
-__all__ = ["test_numeral", "test_dt", "test_translit"]
+__all__ = ["test_common", "test_numeral", "test_dt", "test_translit"]
 
 import unittest
 
