@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-# pytils - simple processing for russian strings
-# Copyright (C) 2006-2007  Yury Yurevich
+# pytils - russian-specific string utils
+# Copyright (C) 2006-2008  Yury Yurevich
 #
 # http://www.pyobject.ru/projects/pytils/
 #
@@ -17,24 +17,32 @@
 Helpers for templatetags' unit tests in Django webframework
 """
 
-__id__ = __revision__ = "$Id: helpers.py 102 2007-07-12 12:33:36Z the.pythy $"
-__url__ = "$URL: https://pythy.googlecode.com/svn/tags/pytils/0_2_2/pytils/test/templatetags/helpers.py $"
-
 from django.conf import settings
 
+encoding = 'utf-8'
+
 settings.configure(
     TEMPLATE_DIRS=(),
     TEMPLATE_CONTEXT_PROCESSORS=(),
     TEMPLATE_LOADERS=(),
     INSTALLED_APPS=('pytils',),
+    DEFAULT_CHARSET=encoding,
 )
 
 from django import template
 from django.template import loader
+from pytils.templatetags import pseudo_str
 
 import unittest
 
 
+def pstr(ustr):
+    """
+    Provide/Pseudo unicode
+    """
+    return pseudo_str(ustr, encoding, None)
+
+
 class TemplateTagTestCase(unittest.TestCase):
     """
     TestCase for testing template tags and filters
@@ -47,20 +55,20 @@ class TemplateTagTestCase(unittest.TestCase):
         @type template_name: C{str}
         
         @param template_string: contents of template
-        @type template_string: C{str}
+        @type template_string: C{str} or C{unicode}
 
         @param context: rendering context
         @type context: C{dict}
 
         @param result_string: reference output
-        @type result_string: C{str}
+        @type result_string: C{str} or C{unicode}
         """
         
         def test_template_loader(template_name, template_dirs=None):
-            return template_string, template_name
+            return pstr(template_string), template_name
         
         loader.template_source_loaders = [test_template_loader,]
         
         output = loader.get_template(template_name).render(template.Context(context))
-        
-        self.assertEquals(output, result_string)
+        self.assertEquals(output, pstr(result_string))
+
