@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-# pytils - simple processing for russian strings
-# Copyright (C) 2006-2007  Yury Yurevich
+# pytils - russian-specific string utils
+# Copyright (C) 2006-2008  Yury Yurevich
 #
 # http://www.pyobject.ru/projects/pytils/
 #
@@ -17,40 +17,40 @@
 Unit tests for pytils' translit templatetags for Django web framework
 """
 
-__id__ = __revision__ = "$Id: test_translit.py 102 2007-07-12 12:33:36Z the.pythy $"
-__url__ = "$URL: https://pythy.googlecode.com/svn/tags/pytils/0_2_2/pytils/test/templatetags/test_translit.py $"
-
 from pytils.test.templatetags import helpers
 
 class TranslitDefaultTestCase(helpers.TemplateTagTestCase):
     
     def testLoad(self):
-        self.check_template_tag('load_tag', '{% load pytils_translit %}', {}, '')
+        self.check_template_tag('load_tag', u'{% load pytils_translit %}', {}, u'')
     
     def testTranslifyFilter(self):
         self.check_template_tag('translify_filter', 
-            '{% load pytils_translit %}{{ val|translify }}', 
+            u'{% load pytils_translit %}{{ val|translify }}', 
             {'val': 'проверка'}, 
-            'proverka')
+            u'proverka')
     
     def testDetranslifyFilter(self):
         self.check_template_tag('detranslify_filter', 
-            '{% load pytils_translit %}{{ val|detranslify }}', 
+            u'{% load pytils_translit %}{{ val|detranslify }}', 
             {'val': 'proverka'}, 
-            'проверка')        
+            u'проверка')
 
     def testSlugifyFilter(self):
         self.check_template_tag('slugify_filter', 
-            '{% load pytils_translit %}{{ val|slugify }}', 
+            u'{% load pytils_translit %}{{ val|slugify }}', 
             {'val': 'Проверка связи'}, 
-            'proverka-svyazi')
+            u'proverka-svyazi')
     
     # без отладки, если ошибка -- по умолчанию пустая строка
     def testDetranslifyError(self):
-        self.check_template_tag('detranslify_error', 
-            '{% load pytils_translit %}{{ val|detranslify }}', 
-            {'val': 'Проверка связи'}, 
-            '')
+        # в юникод-режиме это не ошибка
+        from pytils.templatetags import unicode_aware
+        if not unicode_aware:
+            self.check_template_tag('detranslify_error', 
+                u'{% load pytils_translit %}{{ val|detranslify }}', 
+                {'val': 'Проверка связи'}, 
+                u'')
 
 
 if __name__ == '__main__':
