@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-# pytils - simple processing for russian strings
-# Copyright (C) 2006-2007  Yury Yurevich
+# pytils - russian-specific string utils
+# Copyright (C) 2006-2008  Yury Yurevich
 #
 # http://www.pyobject.ru/projects/pytils/
 #
@@ -17,9 +17,6 @@
 Unit-tests for pytils.dt
 """
 
-__id__ = __revision__ = "$Id: test_dt.py 102 2007-07-12 12:33:36Z the.pythy $"
-__url__ = "$URL: https://pythy.googlecode.com/svn/tags/pytils/0_2_2/pytils/test/test_dt.py $"
-
 import datetime
 import time
 import unittest
@@ -205,6 +202,9 @@ class DistanceOfTimeInWordsTestCase(unittest.TestCase):
         self.assertRaises(TypeError, pytils.dt.distance_of_time_in_words, "test")
         self.assertRaises(TypeError, pytils.dt.distance_of_time_in_words, time.time(), "test")
         self.assertRaises(TypeError, pytils.dt.distance_of_time_in_words, time.time(), 2, "test")
+        self.assertRaises(pytils.err.InputParameterError, pytils.dt.distance_of_time_in_words, "test")
+        self.assertRaises(pytils.err.InputParameterError, pytils.dt.distance_of_time_in_words, time.time(), "test")
+        self.assertRaises(pytils.err.InputParameterError, pytils.dt.distance_of_time_in_words, time.time(), 2, "test")
         self.assertRaises(ValueError, pytils.dt.distance_of_time_in_words, time.time(), 0)
     
     def testIssue25DaysFixed(self):
@@ -307,6 +307,8 @@ class RuStrftimeTestCase(unittest.TestCase):
         """
         self.assertRaises(TypeError, pytils.dt.ru_strftime, time.time())
         self.assertRaises(TypeError, pytils.dt.ru_strftime, u"%Y.%m.%d%", time.time())
+        self.assertRaises(pytils.err.InputParameterError, pytils.dt.ru_strftime, time.time())
+        self.assertRaises(pytils.err.InputParameterError, pytils.dt.ru_strftime, u"%Y.%m.%d%", time.time())
 
     def testIssue20Fixed(self):
         """
