@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-# pytils - simple processing for russian strings
-# Copyright (C) 2006-2007  Yury Yurevich
+# pytils - russian-specific string utils
+# Copyright (C) 2006-2008  Yury Yurevich
 #
 # http://www.pyobject.ru/projects/pytils/
 #
@@ -17,9 +17,6 @@
 Unit-tests for pytils.numeral
 """
 
-__id__ = __revision__ = "$Id: test_numeral.py 102 2007-07-12 12:33:36Z the.pythy $"
-__url__ = "$URL: https://pythy.googlecode.com/svn/tags/pytils/0_2_2/pytils/test/test_numeral.py $"
-
 import unittest
 import pytils
 
@@ -61,6 +58,10 @@ class ChoosePluralTestCase(unittest.TestCase):
                           "25", u"any,bene,raba")
         self.assertRaises(TypeError, pytils.numeral.choose_plural,
                           25, 30)
+        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.choose_plural,
+                          "25", u"any,bene,raba")
+        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.choose_plural,
+                          25, 30)
         self.assertRaises(ValueError, pytils.numeral.choose_plural,
                           25, u"any,bene")
         self.assertRaises(ValueError, pytils.numeral.choose_plural,
@@ -152,6 +153,7 @@ class GetFloatRemainderTestCase(unittest.TestCase):
         self.assertRaises(ValueError, pytils.numeral._get_float_remainder,
                           2.998, 2)
         self.assertRaises(TypeError, pytils.numeral._get_float_remainder, "1.23")
+        self.assertRaises(pytils.err.InputParameterError, pytils.numeral._get_float_remainder, "1.23")
         self.assertRaises(ValueError, pytils.numeral._get_float_remainder, -1.23)
 
 class RublesTestCase(unittest.TestCase):
@@ -183,6 +185,7 @@ class RublesTestCase(unittest.TestCase):
         Unit-test for testing rubles' exceptions
         """
         self.assertRaises(TypeError, pytils.numeral.rubles, "3")
+        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.rubles, "3")
         self.assertRaises(ValueError, pytils.numeral.rubles, -15)
         
 
@@ -211,6 +214,7 @@ class InWordsTestCase(unittest.TestCase):
         Unit-test for testing in_words_int's exceptions
         """
         self.assertRaises(TypeError, pytils.numeral.in_words_int, 2.5)
+        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.in_words_int, 2.5)
         self.assertRaises(ValueError, pytils.numeral.in_words_int, -3)
 
     def testFloat(self):
@@ -232,6 +236,8 @@ class InWordsTestCase(unittest.TestCase):
         """
         self.assertRaises(TypeError, pytils.numeral.in_words_float, '2')
         self.assertRaises(TypeError, pytils.numeral.in_words_float, 2)
+        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.in_words_float, '2')
+        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.in_words_float, 2)
         self.assertRaises(ValueError, pytils.numeral.in_words_float, -2.3)        
 
     def testWithGenderOldStyle(self):
@@ -304,7 +310,10 @@ class InWordsTestCase(unittest.TestCase):
         """
         self.assertRaises(TypeError, pytils.numeral.in_words, "0.2")
         self.assertRaises(TypeError, pytils.numeral.in_words, 0.2, "1")
-        self.assertRaises(ValueError, pytils.numeral.in_words, 0.2, 5)
+        self.assertRaises(TypeError, pytils.numeral.in_words, 0.2, 5)
+        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.in_words, "0.2")
+        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.in_words, 0.2, "1")
+        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.in_words, 0.2, 5)
         self.assertRaises(ValueError, pytils.numeral.in_words, -2)
         
 
@@ -409,7 +418,17 @@ class SumStringTestCase(unittest.TestCase):
                                       1, "1", 23)
         self.assertRaises(TypeError, pytils.numeral.sum_string,
                                       1, pytils.numeral.MALE, (23,24,25))
-        self.assertRaises(ValueError, pytils.numeral.sum_string,
+        self.assertRaises(TypeError, pytils.numeral.sum_string,
+                                      1, pytils.numeral.MALE, (23,))
+        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.sum_string,
+                                      "1", 1)
+        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.sum_string,
+                                      1, "1")
+        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.sum_string,
+                                      1, "1", 23)
+        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.sum_string,
+                                      1, pytils.numeral.MALE, (23,24,25))
+        self.assertRaises(pytils.err.InputParameterError, pytils.numeral.sum_string,
                                       1, pytils.numeral.MALE, (23,))
         self.assertRaises(ValueError, pytils.numeral.sum_string,
                                       -1, pytils.numeral.MALE, u"any,bene,raba")
