@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-# pytils - simple processing for russian strings
-# Copyright (C) 2006-2007  Yury Yurevich
+# pytils - russian-specific string utils
+# Copyright (C) 2006-2008  Yury Yurevich
 #
 # http://www.pyobject.ru/projects/pytils/
 #
@@ -17,10 +17,6 @@
 Unit-tests for pytils.translit
 """
 
-
-__id__ = __revision__ = "$Id: test_translit.py 102 2007-07-12 12:33:36Z the.pythy $"
-__url__ = "$URL: https://pythy.googlecode.com/svn/tags/pytils/0_2_2/pytils/test/test_translit.py $"
-
 import unittest
 
 import pytils
@@ -63,6 +59,7 @@ class TranslitTestCase(unittest.TestCase):
         Unit-test for testing translify's exceptions
         """
         self.assertRaises(TypeError, pytils.translit.translify, 25)
+        self.assertRaises(pytils.err.InputParameterError, pytils.translit.translify, 25)
         self.assertRaises(ValueError, pytils.translit.translify, u'\u00bfHabla espa\u00f1ol?')
 
     def testDetransliteration(self):
@@ -80,6 +77,7 @@ class TranslitTestCase(unittest.TestCase):
         Unit-test for testing detranslify's exceptions
         """
         self.assertRaises(TypeError, pytils.translit.detranslify, 25)
+        self.assertRaises(pytils.err.InputParameterError, pytils.translit.detranslify, 25)
         self.assertRaises(ValueError, pytils.translit.detranslify, "тест")
 
     def testSlug(self):
@@ -96,6 +94,7 @@ class TranslitTestCase(unittest.TestCase):
         Unit-test for testing slugify's exceptions
         """
         self.assertRaises(TypeError, pytils.translit.slugify, 25)
+        self.assertRaises(pytils.err.InputParameterError, pytils.translit.slugify, 25)
         self.assertRaises(ValueError, pytils.translit.slugify, "тест")
 
     def testTranslifyAdditionalUnicodeSymbols(self):
